@@ -41,7 +41,7 @@ use constant DEFAULT_WINDOW_INTERVAL => 5; ## no critic (ValuesAndExpressions::P
 use constant SECONDS_IN_MINUTE => 60; ## no critic (ValuesAndExpressions::ProhibitConstantPragma)
 use constant SECONDS_IN_HOUR => 3600; ## no critic (ValuesAndExpressions::ProhibitConstantPragma)
 
-our $VERSION = '1.0.17';
+our $VERSION = '1.0.18';
 
 # we only log at debug level, create a default logger
 {
@@ -65,6 +65,8 @@ sub new {
 
   my $self = $class->SUPER::new($options);
 
+  $self->set_debug( $ENV{DEBUG} // $self->get_debug ) ;
+  
   if ( !$self->get_logger || reftype( $self->get_logger ) ne 'CODE' ) {
     $self->set_logger( bless { debug => $self->get_debug },
       'Amazon::Credentials::Logger' );
@@ -86,6 +88,8 @@ sub new {
     $self->set_order(DEFAULT_SEARCH_ORDER);
   }
 
+  $self->get_logger->debug('order ' . $self->get_order);
+                           
   if ( !$self->get_aws_secret_access_key || !$self->get_aws_access_key_id ) {
     $self->set_credentials;
   }
@@ -201,6 +205,8 @@ sub find_credentials {
   );
 
   foreach my $location (@search_order) {
+    $self->get_logger->debug('searching for credentials: ' . $location);
+    
     if ( $creds_getters{$location} ) {
       $creds = $creds_getters{$location}->();
     }
@@ -323,9 +329,9 @@ sub get_creds_from_ini_file {
   my $creds = {};
   my $cwd   = $CWD;
 
-  foreach my $config (qw{ aws/config .aws/credentials }) {
+  foreach my $config (qw{ .aws/config .aws/credentials }) {
     last if $creds->{source};
-
+    
     my $profile_name = $profile;
 
     $CWD = home;
@@ -333,7 +339,8 @@ sub get_creds_from_ini_file {
     next if !-e $config;
 
     my $ini = Config::Tiny->read($config);
-
+    $self->get_logger->debug(Dumper($ini));
+    
     if ( $profile eq 'default' ) {
       next if !$ini->{default}->{profile};
 
